@@ -10,8 +10,7 @@ ergmm.statseval <- function (mcmc.out, model, start, prior, control,Z.ref=NULL,Z
   sample.size <- control[["sample.size"]]
 
   if(!is.null(Z.ref)){
-    Z.ref<-scale(Z.ref,scale=FALSE)
-    control[["Z.ref"]]<-Z.ref
+    control[["Z.ref"]]<-scale(model, list(Z=Z.ref))
   }
   if(!is.null(Z.K.ref)){
     control[["Z.K.ref"]]<-Z.K.ref
@@ -39,9 +38,9 @@ ergmm.statseval <- function (mcmc.out, model, start, prior, control,Z.ref=NULL,Z
 
 statsreeval.ergmm<-function(x,Z.ref=NULL,Z.K.ref=NULL,rerun=FALSE){
   if(!is.null(Z.ref)){
-    Z.ref<-scale(Z.ref,scale=FALSE)
-    x[["control"]][["Z.ref"]]<-Z.ref
+    control[["Z.ref"]]<-scale(x[["model"]], list(Z=Z.ref))
   }
+  
   if(!is.null(Z.K.ref)){
     x[["control"]][["Z.K.ref"]]<-Z.K.ref
   }
@@ -118,11 +117,11 @@ add.mcmc.mle.mle.ergmm<-function(x,Z.ref=best.avail.Z.ref.ergmm(x)){
   
   x[["mle"]]<-scale(x[["model"]],x[["mle"]])
 
-  if(x[["model"]][["d"]]){
+  if(x[["model"]][["d"]] && "rotation" %in% latent.effect.invariances[[x[["model"]][["familyID"]]]]){
     if(!require(shapes,quietly=TRUE)){
       stop("You need the 'shapes' package to summarize the fit of latent cluster models.")
     }
-    x[["mle"]][["Z"]]<-procOPA(Z.ref,x[["mle"]][["Z"]],scale=FALSE,reflect=TRUE)[["Bhat"]]
+    x[["mle"]][["Z"]]<-procOPA(x[["model"]],Z.ref,x[["mle"]][["Z"]])[["Bhat"]]
   }
   
   x
@@ -155,11 +154,11 @@ add.mcmc.pmode.pmode.ergmm<-function(x,Z.ref=best.avail.Z.ref.ergmm(x)){
   if(is.null(x[["pmode"]]) || pmode2[["mlp"]]>x[["pmode"]][["mlp"]]) x[["pmode"]]<-pmode2
     
   if(x[["model"]][["d"]]>0 && !is.null(x[["pmode"]])){
-    Z<-scale(x[["pmode"]][["Z"]],scale=FALSE)
+    x[["pmode"]]<-scale(x[["model"]], x[["pmode"]])
     if(!require(shapes,quietly=TRUE)){
       stop("You need the 'shapes' package to summarize the fit of latent cluster models.")
     }
-    P<-procOPA(Z.ref,Z,scale=FALSE,reflect=TRUE)[["R"]]
+    P<-procOPA(x[["model"]],Z.ref,x[["pmode"]][["Z"]])[["R"]]
     x[["pmode"]][["Z"]]<-x[["pmode"]][["Z"]]%*%P
     if(!is.null(x[["pmode"]][["Z.mean"]]))
       x[["pmode"]][["Z.mean"]]<-x[["pmode"]][["Z.mean"]]%*%P
@@ -188,13 +187,13 @@ add.mkl.pos.ergmm<-function(x, Z.ref=best.avail.Z.ref.ergmm(x)){
     }
   }
   if(!is.null(x[["mkl"]][["Z"]])) x[["mkl"]]<-scale(x[["model"]],x[["mkl"]])
-  if(!is.null(x[["mkl"]][["Z"]])) x[["mkl"]][["Z"]]<-procOPA(Z.ref,x[["mkl"]][["Z"]],scale=FALSE,reflect=TRUE)[["Bhat"]]
+  if(!is.null(x[["mkl"]][["Z"]])) x[["mkl"]][["Z"]]<-procOPA(x[["model"]],Z.ref,x[["mkl"]][["Z"]])[["Bhat"]]
   if(x[["control"]][["verbose"]]) cat("Finished.\n")
   x
 }
 
 proc.sample.ergmm<-function(x,Z.ref=best.avail.Z.ref.ergmm(x)){
-  if(!is.null(x[["sample"]]) && x[["model"]][["d"]]>0){
+  if(!is.null(x[["sample"]]) && x[["model"]][["d"]]>0 && "rotation" %in% latent.effect.invariances[[x[["model"]][["latentID"]]]] && "reflection" %in% latent.effect.invariances[[x[["model"]][["latentID"]]]]){
     if(x[["control"]][["verbose"]]) cat("Performing Procrustes transformation... ")
     x[["sample"]]<-proc.Z.mean.C(x[["sample"]],Z.ref,verbose=x[["control"]][["verbose"]])
     if(x[["control"]][["verbose"]]) cat("Finished.\n")
@@ -244,19 +243,25 @@ best.avail.Z.K.ref.ergmm<-function(x){
 }
 
 # We are overriding the generic for "scale" to make it more flexible.
-scale<-function (x,...) 
-  UseMethod("scale")
+scale<-function (x, ...) UseMethod("scale")
 
 scale.ergmm.model<-function(x,theta,...){
   extraneous.argcheck(...)
   if(!is.null(theta[["Z"]])){
-    if(!is.null(theta[["Z.mean"]])){
-      Z.center<-colMeans(theta[["Z.mean"]])
-      theta[["Z.mean"]]<-sweep(theta[["Z.mean"]],2,Z.center,check.margin=FALSE)
-    }else{
-      Z.center<-colMeans(theta[["Z"]])
+    if("translation" %in% latent.effect.invariances[[x[["latentID"]]]]){
+      if(!is.null(theta[["Z.mean"]])){
+        Z.center<-colMeans(theta[["Z.mean"]])
+        theta[["Z.mean"]]<-sweep(theta[["Z.mean"]],2,Z.center,check.margin=FALSE)
+      }else{
+        Z.center<-colMeans(theta[["Z"]])
+      }
+      theta[["Z"]]<-sweep(theta[["Z"]],2,Z.center,check.margin=FALSE)
+    }
+    if("scaling" %in% latent.effect.invariances[[x[["latentID"]]]]){
+      theta[["Z"]]<-scale(theta[["Z"]],center=FALSE)
+      theta[["Z.mean"]]<-scale(theta[["Z.mean"]],center=FALSE)
+      ## Fixme: Should Z.var be scaled as well? How?
     }
-    theta[["Z"]]<-sweep(theta[["Z"]],2,Z.center,check.margin=FALSE)
   }
   if(x[["intercept"]]){
     shift<-0
@@ -278,3 +283,12 @@ scale.ergmm.model<-function(x,theta,...){
   }
   theta
 }
+
+# We are overriding "procOPA" to make it more flexible.
+procOPA <- function(x, ...) UseMethod("procOPA")
+
+procOPA.default <- function(x, ...) shapes::procOPA(x, ...)
+
+procOPA.ergmm.model<-function (x,A,B,...){
+  procOPA(A,B,scale="scaling" %in% latent.effect.invariances[[x[["latentID"]]]],reflect="reflection" %in% latent.effect.invariances[[x[["latentID"]]]])
+}
