@@ -37,9 +37,12 @@ thin.ergmm<-function(x,by){
   x
 }
 
-xtabs.ergmm<-function(x,ref){
+xtabs.ergmm<-function(x,ref,min.plurality=0){
   ref->Reference
   apply(attr(x[["sample"]],"Q"),1,which.max)->Fitted
+  admit<-sapply(seq_along(Fitted), function(i) attr(x[["sample"]],"Q")[i,Fitted[i]]>=min.plurality)
+  Reference<-Reference[admit]
+  Fitted<-Fitted[admit]
   xtabs(~Reference+Fitted)
 }
 
