@@ -3,7 +3,7 @@ data(sampson)
 ym<-as.matrix(samplike)
 ym[1,5]<-NA
 yg<-as.network(ym,matrix.type="adjacency")
-samp.fit<-ergmm(yg~latent(d=2))
+samp.fit<-ergmm(yg~euclidean(d=2))
 
 print(summary(samp.fit))
 plot(samp.fit,labels=TRUE)
